# to estimate the level of ideological bias using the left-right scale
use countries_left_right.dta, clear
# exp_lr is the left-right position of expert from the unfolding analysis
sort party
by party: gen bias=1 if  score99<=10
recode  bias (.=-1) if score99!=.
sort party
by party: egen mean_lr= mean(score13)
gen diff_lr = (exp_lr-mean_lr)*bias if score13!=.

gen LRcrm =  . 
label var LRcrm "Corrected LR mean, manual"
gen LRcrse = . 
label var LRcrse "Corrected LR s.e., manual"
gen LRmean = .
label var LRmean "Original LR mean, manual"
gen LRse = . 
label var LRse "Original LR s.e., manual"
gen b0 = .
gen b1 = .
gen b0se = .
gen b1se = .
gen N = .

levels country, local(plist)
foreach p of local plist {
	quietly levels partynam if country==`p', local(clist) 
    	foreach c of local clist {
	quietly ci score13 if country==`p' & partynam==`c' & score99!=.
	quietly replace LRmean = r(mean) if country==`p' & partynam==`c'
	local n = r(N)
	quietly replace LRse = r(se) if country==`p' & partynam==`c'
	di "partynam `c'"
	reg score13 diff_lr if country==`p' & partynam==`c', robust
	matrix b = e(b)
	matrix vc = e(V)
      local sigma = e(rmse)
	local n = e(N)
      local b1 = b[1,1]
	local b0 = b[1,2]
	replace b0 = `b0' if country==`p' & partynam==`c'
	replace b1 = `b1' if country==`p' & partynam==`c'
	replace b1se =  sqrt(vc[1,1]) if country==`p' & partynam==`c'
	replace b0se =  sqrt(vc[2,2]) if country==`p' & partynam==`c'
	replace N = `n' if country==`p' & partynam==`c'
	gen mean_lr_party = score13 -(`b1'*diff_lr) if country==`p' & partynam==`c'
	quietly recode mean_lr_party (min/1=1) (20/max=20) if country==`p' & partynam==`c'
	quietly ci mean_lr_party if country==`p' & partynam==`c'
	quietly replace LRcrm = r(mean) if country==`p' & partynam==`c'
	local n = r(N)
	quietly replace LRcrse = r(se) if country==`p' & partynam==`c'
	quietly drop mean_lr_party
       }
    }

gen LRdev = LRmean - LRcrm
gen LRdevse = sqrt(LRse^2 + LRcrse^2)
gen testt = LRdev/LRdevse


# to estimate the level of ideological bias using the taxes vs. spending policy dimension
use countries_taxes.dta, clear
# exp_tax is the taxes vs. spending policy position of expert from the unfolding analysis
sort party
by party: gen bias=1 if  score99<=10
recode  bias (.=-1) if score99!=.
sort party
by party: egen mean_tax= mean(score1)
gen diff_tax = (exp_tax-mean_tax)*bias if score1!=.

gen TAXcrm =  . 
label var TAXcrm "Corrected TAXES mean, manual"
gen TAXcrse = . 
label var TAXcrse "Corrected TAXES s.e., manual"
gen TAXmean = .
label var TAXmean "Original TAXES mean, manual"
gen TAXse = . 
label var TAXse "Original TAXES s.e., manual"
gen b0_t = .
gen b1_t = .
gen b0se_t = .
gen b1se_t = .
gen N_t = .

levels country, local(plist)
foreach p of local plist {
	quietly levels partynam if country==`p', local(clist) 
    	foreach c of local clist {
	quietly ci score1 if country==`p' & partynam==`c' & score99!=.
	quietly replace TAXmean = r(mean) if country==`p' & partynam==`c'
	local n = r(N)
	quietly replace TAXse = r(se) if country==`p' & partynam==`c'
	di "partynam `c'"
	reg score1 diff_tax if country==`p' & partynam==`c', robust
	matrix b = e(b)
	matrix vc = e(V)
      local sigma = e(rmse)
	local n = e(N)
      local b1 = b[1,1]
	local b0 = b[1,2]
	replace b0_t = `b0' if country==`p' & partynam==`c'
	replace b1_t = `b1' if country==`p' & partynam==`c'
	replace b1se_t =  sqrt(vc[1,1]) if country==`p' & partynam==`c'
	replace b0se_t =  sqrt(vc[2,2]) if country==`p' & partynam==`c'
	replace N_t = `n' if country==`p' & partynam==`c'
	gen mean_tax_party = score1 -(`b1'*diff_tax) if country==`p' & partynam==`c'
	quietly recode mean_tax_party (min/1=1) (20/max=20) if country==`p' & partynam==`c'
	quietly ci mean_tax_party if country==`p' & partynam==`c'
	quietly replace TAXcrm = r(mean) if country==`p' & partynam==`c'
	local n = r(N)
	quietly replace TAXcrse = r(se) if country==`p' & partynam==`c'
	quietly drop mean_tax_party
       }
    }

gen TAXdev = TAXmean - TAXcrm
gen TAXdevse = sqrt(TAXse^2 + TAXcrse^2)
gen testt_tax = TAXdev/TAXdevse


# to estimate the level of ideological bias using the social policy dimension
use countries_social.dta, clear
# exp_soc is the social policy position of expert from the unfolding analysis
sort party
by party: gen bias=1 if  score99<=10
recode  bias (.=-1) if score99!=.
sort party
by party: egen mean_soc= mean(score2)
gen diff_soc = (exp_soc-mean_soc)*bias if score2!=.

gen SOCcrm =  . 
label var SOCcrm "Corrected SOCIAL mean, manual"
gen SOCcrse = . 
label var SOCcrse "Corrected SOCIAL s.e., manual"
gen SOCmean = .
label var SOCmean "Original SOCIAL mean, manual"
gen SOCse = . 
label var SOCse "Original SOCIAL s.e., manual"
gen b0_s = .
gen b1_s = .
gen b0se_s = .
gen b1se_s = .
gen N_s = .

levels country, local(plist)
foreach p of local plist {
	quietly levels partynam if country==`p', local(clist) 
    	foreach c of local clist {
	quietly ci score2 if country==`p' & partynam==`c' & score99!=.
	quietly replace SOCmean = r(mean) if country==`p' & partynam==`c'
	local n = r(N)
	quietly replace SOCse = r(se) if country==`p' & partynam==`c'
	di "partynam `c'"
	reg score2 diff_soc if country==`p' & partynam==`c', robust
	matrix b = e(b)
	matrix vc = e(V)
      local sigma = e(rmse)
	local n = e(N)
      local b1 = b[1,1]
	local b0 = b[1,2]
	replace b0_s = `b0' if country==`p' & partynam==`c'
	replace b1_s = `b1' if country==`p' & partynam==`c'
	replace b1se_s =  sqrt(vc[1,1]) if country==`p' & partynam==`c'
	replace b0se_s =  sqrt(vc[2,2]) if country==`p' & partynam==`c'
	replace N_s = `n' if country==`p' & partynam==`c'
	gen mean_soc_party = score2 -(`b1'*diff_soc) if country==`p' & partynam==`c'
	quietly recode mean_soc_party (min/1=1) (20/max=20) if country==`p' & partynam==`c'
	quietly ci mean_soc_party if country==`p' & partynam==`c'
	quietly replace SOCcrm = r(mean) if country==`p' & partynam==`c'
	local n = r(N)
	quietly replace SOCcrse = r(se) if country==`p' & partynam==`c'
	quietly drop mean_soc_party
       }
    }

gen SOCdev = SOCmean - SOCcrm
gen SOCdevse = sqrt(SOCse^2 + SOCcrse^2)
gen testt_SOC = SOCdev/SOCdevse
